@@ -172,13 +172,13 @@ def t_demo10():
 
 if __name__ == '__main__':
     pass
-    # t_demo0()
-    # t_demo1()
-    # t_demo2()
+    t_demo0()
+    t_demo1()
+    t_demo2()
     # t_demo3()
-    # t_demo4()
+    t_demo4()
     # t_demo5()
-    # t_demo6()
-    # t_demo7()
-    # t_demo9()
+    t_demo6()
+    t_demo7()
+    t_demo9()
     t_demo10()
